@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Response::Artist;
 use strict;
 use base 'Class::Accessor';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -15,7 +15,7 @@ WebService::MusicBrainz::Response::Artist
 
 =head1 METHODS
 
-All the methods listed below are accessor methods.  They can take a scalar argument to set the state of the object or without and argument, they will return that state if it is available.
+All the methods listed below are accessor methods.  They can take a scalar argument to set the state of the object or without an argument, they will return that state if it is available.
 
 =head2 id()
 
@@ -37,11 +37,11 @@ All the methods listed below are accessor methods.  They can take a scalar argum
 
 =head2 relation_list()
 
-=head2 extension()
+=head2 score()
 
 =cut
 
-__PACKAGE__->mk_accessors(qw/id type name sort_name disambiguation life_span_begin life_span_end alias_list release_list relation_list extension/);
+__PACKAGE__->mk_accessors(qw/id type name sort_name disambiguation life_span_begin life_span_end alias_list release_list relation_list score/);
 
 =head1 AUTHOR
 
