@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Response::Relation;
 use strict;
 use base 'Class::Accessor';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -35,11 +35,11 @@ All the methods listed below are accessor methods.  They can take a scalar argum
 
 =head2 track()
 
-=head2 extension()
+=head2 score()
 
 =cut
 
-__PACKAGE__->mk_accessors(qw/type target direction attributes begin end artist release track extension/);
+__PACKAGE__->mk_accessors(qw/type target direction attributes begin end artist release track score/);
 
 =head1 AUTHOR
 
