@@ -3,7 +3,7 @@ package WebService::MusicBrainz::Response::Release;
 use strict;
 use base 'Class::Accessor';
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 =head1 NAME
 
@@ -41,11 +41,11 @@ All the methods listed below are accessor methods.  They can take a scalar argum
 
 =head2 relation_list()
 
-=head2 extension()
+=head2 score()
 
 =cut
 
-__PACKAGE__->mk_accessors(qw/id type title text_rep_language text_rep_script asin artist release_event_list disc_list puid_list track_list relation_list extension/);
+__PACKAGE__->mk_accessors(qw/id type title text_rep_language text_rep_script asin artist release_event_list disc_list puid_list track_list relation_list score/);
 
 =head1 AUTHOR
 
